package test.matchers;

import java.util.List;
import java.util.HashMap;
import java.util.Iterator;
import java.util.ArrayList;

import junit.framework.TestCase;
import junit.framework.Test;
import junit.framework.TestSuite;

import javax.provisioning.matcher.*;

public class PreferenceMatcherTest extends TestCase {

    private List preferenceMatchers;

    public PreferenceMatcherTest(String name) {
        super(name);
    }

    public void testPreferenceMatcher() {
        Iterator i = preferenceMatchers.iterator();
        while (i.hasNext()) {
            PreferenceMatcher matcher = (PreferenceMatcher) i.next();
            testMatchValues(matcher);
        }
    }

    public void setUp() {
        PreferenceMatcher ttt = new PreferenceMatcher();
        PreferenceMatcher ttf = new PreferenceMatcher();
        PreferenceMatcher tft = new PreferenceMatcher();
        PreferenceMatcher tff = new PreferenceMatcher();
        PreferenceMatcher ftt = new PreferenceMatcher();
        PreferenceMatcher ftf = new PreferenceMatcher();
        PreferenceMatcher fft = new PreferenceMatcher();
        PreferenceMatcher fff = new PreferenceMatcher();

        try {
            ttt.init("TTT", getParamMap("true", "true", "true"));
            ttf.init("TTF", getParamMap("true", "true", "false"));
            tft.init("TFT", getParamMap("true", "false", "true"));
            tff.init("TFF", getParamMap("true", "false", "false"));
            ftt.init("FTT", getParamMap("false", "true", "true"));
            ftf.init("FTF", getParamMap("false", "true", "false"));
            fft.init("FFT", getParamMap("false", "false", "true"));
            fff.init("FFF", getParamMap("false", "false", "false"));
        } catch (MatcherException e) {
            e.printStackTrace();
        }

        preferenceMatchers = new ArrayList();

        preferenceMatchers.add(ttt);
        preferenceMatchers.add(ttf);
        preferenceMatchers.add(tft);
        preferenceMatchers.add(tff);
        preferenceMatchers.add(ftt);
        preferenceMatchers.add(ftf);
        preferenceMatchers.add(fft);
        preferenceMatchers.add(fff);
    }

    private HashMap getParamMap(String allMustMatch, String caseInsensitive, String wildcardsOn) {
        HashMap initParams = new HashMap();
        initParams.put("allMustMatch", allMustMatch);
        initParams.put("caseInsensitive", caseInsensitive);
        initParams.put("wildcardsOn", wildcardsOn);
        return initParams;
    }

    private float matchValue(String requirement, String capability, PreferenceMatcher matcher) {
        List capabilities = new ArrayList();
        capabilities.add(capability);

        List requirements = new ArrayList();
        requirements.add(requirement);

        try {
            float f = matcher.match(requirements, capabilities);
            return f;
        } catch (MatcherException e) {
            e.printStackTrace();
        }
        return -1f;
    }

    private float matchCapabilities(String requirement, List capabilities, PreferenceMatcher matcher) {
        List requirements = new ArrayList();
        requirements.add(requirement);

        try {
            float f = matcher.match(requirements, capabilities);
            return f;
        } catch (MatcherException e) {
            e.printStackTrace();
        }
        return -1f;
    }

    private void testMatchValues(PreferenceMatcher matcher) {
        List capabilities = new ArrayList();
        capabilities.add("en");
        capabilities.add("fr");
        capabilities.add("ge");

        float f = matchCapabilities("en", capabilities, matcher);
        assertTrue(matcher.getAttributeName(), f == 1f);
        f = matchCapabilities("fr", capabilities, matcher);
        assertTrue(matcher.getAttributeName(), f == 1 / 2f);
        f = matchCapabilities("ge", capabilities, matcher);
        assertTrue(matcher.getAttributeName(), f == 1 / 3f);

        capabilities = new ArrayList();
        capabilities.add("e[a-z]*");
        capabilities.add("fr");
        capabilities.add("ge");
        if (matcher.getWildcardsOn()) {
            f = matchCapabilities("en", capabilities, matcher);
            assertTrue(matcher.getAttributeName(), f == 1f);
        }

        capabilities = new ArrayList();
        capabilities.add("e[a-z]*");
        capabilities.add("[a-z]*");
        capabilities.add("ge");
        if (matcher.getWildcardsOn()) {
            f = matchCapabilities("fr", capabilities, matcher);
            assertTrue(matcher.getAttributeName(), f == 1 / 2f);
        }
    }
}
