package org.jvending.provisioning.config;

import org.jvending.registry.RepositoryRegistry;

import javax.provisioning.Deliverable;
import javax.provisioning.ProvisioningException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.net.MalformedURLException;
import java.util.List;
import java.util.ArrayList;

public class DeliverableRepositoryTest extends BaseConfig {

    private DeliverableRepository deliverableRepository;

    public void setUp() {
        super.setUp();
        deliverableRepository = (DeliverableRepository) repositoryRegistry.find("deliverables");
        assertNotNull("Deliverable Repository is null", deliverableRepository);
    }

    public void testNullUrl() {
        try {
            deliverableRepository.getDeliverableFor(null, new URI("http://localhost:8080"),
                    "text/vnd.sun.j2me.app-descriptor", new ArrayList());
            fail("The deliverable should have thrown an exception when the URL param is null");
        } catch (URISyntaxException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {

        }
    }

    public void testNullUri() {
        try {
            Deliverable deliverable = deliverableRepository.getDeliverableFor(new URL("http://localhost:8080"), null,
                    "text/vnd.sun.j2me.app-descriptor", new ArrayList());
            assertEquals("Incorrect mime type", deliverable.getMimeType(), "text/vnd.sun.j2me.app-descriptor");
            assertEquals("Incorrect URL", new URL("http://localhost:8080"), deliverable.getURL());
        } catch (MalformedURLException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {
            e.printStackTrace();
            fail("Message = " + e.getMessage());
        }
    }

    public void testNullMimeType() {
        try {
            deliverableRepository.getDeliverableFor(new URL("http://localhost:8080"),
                    new URI("http://localhost:8080"), null, new ArrayList());
            fail("The deliverable should have thrown an exception when the mime type param is null");
        } catch (URISyntaxException e) {
            fail("Message = " + e.getMessage());
        } catch (MalformedURLException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {

        }
    }

    public void testEmptyMimeType() {
         try {
            deliverableRepository.getDeliverableFor(new URL("http://localhost:8080"),
                    new URI("http://localhost:8080"), "", new ArrayList());
            fail("The deliverable should have thrown an exception when the mime type param is invalid");
        } catch (URISyntaxException e) {
            fail("Message = " + e.getMessage());
        } catch (MalformedURLException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {

        }
    }

    public void testInvalidMimeType() {
        try {
            deliverableRepository.getDeliverableFor(new URL("http://localhost:8080"),
                    new URI("http://localhost:8080"), "blah-blah", new ArrayList());
            fail("The deliverable should have thrown an exception when the mime type param is invalid");

        } catch (URISyntaxException e) {
            fail("Message = " + e.getMessage());
        } catch (MalformedURLException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {

        }

        try {
            deliverableRepository.getDeliverableFor(new URL("http://localhost:8080"),
                    new URI("http://localhost:8080"), "txt/blah", new ArrayList());
            fail("The deliverable should have thrown an exception when the mime type param is invalid");
        } catch (URISyntaxException e) {
            fail("Message = " + e.getMessage());
        } catch (MalformedURLException e) {
            fail("Message = " + e.getMessage());
        } catch (ProvisioningException e) {

        }
    }
}
