/*
 *  JVending
 *  Copyright (C) 2004  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.deliverable;

import javax.provisioning.DescriptorFile;

import java.util.Collections;
import java.util.List;
import java.util.logging.*;

import java.net.URI;
import java.net.URL;

/**
 *
 * @author Shane Isbell
 * @version 1.3.8a
 */

public abstract class BaseDescriptorFile extends DescriptorFile {

    private static Logger logger = Logger.getLogger("BaseDescriptorFile");

    private final List contentDeliverables;

    private final URI uri;

    /** Use this class if you want the provisioning framework to handle the construction
     *  of content files, otherwise extend from DescriptorFile.
     */
    public BaseDescriptorFile(URL url, URI uri, String mimeType, List contentDeliverables) {
        super(url, mimeType);
        this.uri = uri;
        this.contentDeliverables = contentDeliverables;
    }

    //List of Deliverables
    public List getContentFiles() {
        return Collections.unmodifiableList(contentDeliverables);
    }

    public URI getURI() {
        return uri;
    }
}