/*
 *  JVending - JSP Tag Library
 *  Copyright (C) 2004  Shane Isbell
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.jvending.provisioning.taglib;

import java.io.IOException;

import java.util.Iterator;
import java.util.List;
import java.util.Locale;
import java.util.logging.*;

import javax.provisioning.BundleDescriptor;

import javax.servlet.jsp.JspTagException;
import javax.servlet.jsp.tagext.BodyTagSupport;
import javax.servlet.jsp.tagext.BodyContent;

/**
 * @author Shane Isbell
 * @since 1.3.9a
 */

public class IconsTag extends BodyTagSupport {

    private static Logger logger = Logger.getLogger("IconsTag");

    private StringBuffer buffer = new StringBuffer();

    private String locale;

    private Iterator iconsIterator;

    public void setLocale(String locale) {
        this.locale = (locale == "") ? null: locale;
    }

    public String getLocale() {
        return locale;
    }

    public int doStartTag() throws JspTagException {
        BundleDescriptor descriptor = (BundleDescriptor)
             pageContext.getAttribute("descriptor", 
                                       pageContext.PAGE_SCOPE);
        if(descriptor == null) {
            logger.info("Descriptor is null. Not processing this tag.");
            return SKIP_BODY;
        }

        List icons = (locale != null) ? descriptor.getIcons(new Locale(locale)) : descriptor.getIcons(null);
        
        if(icons == null || icons.size() == 0) {
            logger.finest("No icons. Skipping this tag.");
            return SKIP_BODY;
        }

        iconsIterator = icons.iterator();

        pageContext.setAttribute("icon", iconsIterator.next());
        return EVAL_BODY_BUFFERED;
    }

    public int doEndTag() throws JspTagException {
        BodyContent bodyContent = getBodyContent();
        try {
            if(bodyContent != null) {
                bodyContent.getEnclosingWriter().write(buffer.toString());
            }
        } catch(IOException e) {
            e.printStackTrace();
            throw new JspTagException("Could not End Tag");
        } finally {
            buffer = new StringBuffer();
        }
        return EVAL_PAGE;
    }

    public int doAfterBody() throws JspTagException {     
        BodyContent bodyContent = getBodyContent();
        if(bodyContent != null) {
            buffer.append(bodyContent.getString());
            try {
                bodyContent.clear();
            } catch(IOException e) {
                e.printStackTrace();
            }
        }

       if(iconsIterator == null) return SKIP_BODY;

       if(iconsIterator.hasNext()) {
            pageContext.setAttribute("icon", iconsIterator.next());
            return EVAL_BODY_BUFFERED;
        } else
            return SKIP_BODY;
    }

}
